//=============================================================================
//  MuseScore
//  Linux Music Score Editor
//  $Id:$
//
//  Test plugin
//
//  Copyright (C)2008 Werner Schweer and others
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License version 2.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//=============================================================================

//
//    This is ECMAScript code (ECMA-262 aka "Java Script")
//

//---------------------------------------------------------
//    init
//    this function will be called on startup of
//    mscore
//---------------------------------------------------------

function init()
{
	// print("test script init");
}

//---------------------------------------------------------
//    run
//    this function will be called when activating the
//    plugin menu entry
//
//    global Variables:
//    pluginPath - contains the plugin path; file separator
//                 is "/"
//---------------------------------------------------------
var defaultOpenDir = QDir.homePath();

debug = false;

if(debug)
	defaultOpenDir = "C:\\Dokumente und Einstellungen\\kratzmeier\\Eigene Dateien\\MuseScore-Stcke\\I\\I Am Sailing";

/*
06.12.2011 xml-parsing berarbeitet
*/
function run()
{
	var xml = getXMLDataFromFile();
	
	if(xml == "-1")
		return;
		
	var doc = new QDomDocument();
	doc.setContent(xml); // It's ok, its working.
	
	// get the root element    
	var docElem = doc.documentElement();     
	
	// get the title
	var title = "unknown";
	
	// get the composer
	var composer = "unknown";
	
	init2(docElem);
	
	if(gv.softwareVersion == 1)
	{
		title = getCredit(docElem, "title");
		composer = getCredit(docElem, "composer")
	}
	else if(gv.softwareVersion == 2)
	{
		title = docElem.elementsByTagName("movement-title").at(0).toElement().text();
		composer = docElem.elementsByTagName("creator").at(0).toElement().text();
	}
	
	//  meter, tempo, beats in measure
	var meter = "";
	var tempo = "";
	
	var part1;
	var cntParts = docElem.elementsByTagName("part").count();
	//MB("parts: " + cntParts)
	
	for(var i=0; i<cntParts;i++)
	{
		var part = docElem.elementsByTagName("part").at(i).toElement()
		var part_id = part.attribute('id');
		
		if(part_id == "P1")
		{
			part1 = part;
			break;
		}
	}
	
	// get a list of all measures
	var measureList = part.elementsByTagName("measure"); 	
	
	// counting all measures
	gv.anz_measures = measureList.count();
	gv.harmony_last = "";
	
	// splitting the measures in melody and harmony
	var melody = new Array(gv.anz_measures);
	var harmony = new Array(gv.anz_measures);
	var durationOfMeasure = new Array(gv.anz_measures);
	var key = "";
	var aktMeasure;
	var divisions;
	
	// go through all measures
	//for(var measure = 0; measure < 1; measure++) 
	for(var measure = 0; measure < gv.anz_measures; measure++)    
	{	
		gv.durationOfMeasure = 0;
		
		// get the current one as QDomElement    	
		aktMeasure = measureList.at(measure).toElement();  
			
		divisions = getDivisions(aktMeasure, measure);
		
		if(divisions != "")
		{
			gv.divisions = divisions;
			
			// sets gv.wholeBarDuration
			setWholeBarDuration()
		}
			
		// get the melody of the given measure
		var melodyMeasure = getMelodyOfMeasure(aktMeasure, measure);
		
		if(measure == 0)
		{
			key = getKey(aktMeasure, measure);
			//MB("key: " + key);
			gv.durationOf32tel = gv.divisions/8
			
			// sets gv.beats and gv.beat_type
			meter = getMeter(aktMeasure, measure);
			//MB("meter: " + meter);
			
			tempo = getTempo(aktMeasure, measure);
			
			setWholeBarDuration();
			
			if(gv.durationOfMeasure < gv.wholeBarDuration)
			{
				// melody in measure is incomplete
				// adding rest to complete the bar
				var addedRest = "r";
				var adding = (gv.wholeBarDuration - gv.durationOfMeasure)/gv.durationOf32tel
				
				for(var i=0; i<adding;i++)
				{
					addedRest += "32";
					
					gv.durationOfMeasure += gv.durationOf32tel;
				
					if(i<(adding-1))
						addedRest += "+"
				}
				melodyMeasure = addedRest + " " + melodyMeasure;
				//MB("melodyMeasure: " + melodyMeasure);
			}
		}
		
		// save duration of current measure
		durationOfMeasure[measure] = gv.durationOfMeasure;
		
		// save the melody in an array for each measure
		melody[measure] = melodyMeasure;
		
		// get the harmony of the given measure
		//MB("ms: " + measure);
		var harmonyMeasure = getHarmonyOfMeasure(aktMeasure, measure);
		
		if(harmonyMeasure == "")
		{
			if(gv.harmony_last == "")
				harmonyMeasure = "NC";
			else
				harmonyMeasure = gv.harmony_last
		}
		
		gv.harmony_last = harmonyMeasure;
					
		// save the harmony in an array for each measure
		if(harmonyMeasure.trim().indexOf(" ") < 0)
		{
			if(harmonyMeasure == harmony[measure-1])
				harmony[measure] = "/";
			else
				harmony[measure] = harmonyMeasure;
		}
		else
			harmony[measure] = harmonyMeasure;
	}
	
	// write transformed data to output file (.ls)
	var success = writeFile(title, meter, melody, harmony, composer, tempo, durationOfMeasure, key) ;
	if(success)	MB("Ready.")
} 
function init2(docElem)
{
	// get software-version
	gv.softwareVersion = getSoftwareVersion(docElem);
	
	gv.allChords = new Array(
	"+",
	"-",
	"-6",
	"7",
	"+7",
	"+add#9",
	"0",
	"11",
	"11b9",
	"13",
	"13#11",
	"13#9",
	"13#9#11",
	"13b5",
	"13b9",
	"13b9#11",
	"13no5",
	"13sus",
	"13sus4",
	"2",
	"4",
	"5",
	"6",
	"6#11",
	"67",
	"69",
	"6b5",
	"7",
	"7#11",
	"7#11b13",
	"7#5",
	"7#5#9",
	"7#5b9",
	"7#5b9#11",
	"7#5sus4",
	"7#9",
	"7#9#11",
	"7#9#11b13",
	"7#9b13",
	"7+",
	"7add13",
	"7add6",
	"7alt",
	"40762",
	"7b13",
	"7b5",
	"7b5#9",
	"7b5b13",
	"7b5b9",
	"7b5b9b13",
	"7b6",
	"7b9",
	"7b9#11",
	"7b9#11b13",
	"7b9#9",
	"7b9b13",
	"7b9b13#11",
	"7b9b13sus4",
	"7b9sus",
	"7b9sus4",
	"7b9sus4",
	"7no5",
	"7sus",
	"7sus4",
	"7sus4b9",
	"7sus4b9b13",
	"7susb9",
	"9",
	"9#11",
	"9#11b13",
	"9#5",
	"9#5#11",
	"9+",
	"9b13",
	"9b5",
	"9b5b13",
	"9no5",
	"9sus",
	"9sus4",
	"Bass",
	"Blues",
	"M#5",
	"M#5add9",
	"M13",
	"M13#11",
	"M6",
	"M6#11",
	"M69",
	"M69#11",
	"M6b5",
	"M7",
	"M7#11",
	"M7#5",
	"M7#5sus4",
	"M7#9#11",
	"M7+",
	"M7add13",
	"M7b5",
	"M7b6",
	"M7b9",
	"M7sus4",
	"M9",
	"M9#11",
	"M9#5",
	"M9#5sus4",
	"M9b5",
	"M9sus4",
	"Madd9",
	"Maj#5",
	"Maj13",
	"Maj13#11",
	"Maj7",
	"Maj7#11",
	"Maj7#5",
	"Maj9",
	"Maj9#11",
	"Maj9#5",
	"Mb5",
	"Mb6",
	"Msus2",
	"Msus4",
	"add2",
	"add9",
	"add9no3",
	"addb9",
	"aug",
	"39295",
	"dim",
	"dim7",
	"h11",
	"h7",
	"h9",
	"m",
	"m#5",
	"m+",
	"m11",
	"m11#5",
	"m11b5",
	"m13",
	"m6",
	"m69",
	"m6b5",
	"m7",
	"m7#5",
	"m7add11",
	"m7add4",
	"m7b5",
	"m9",
	"m9#5",
	"m9b5",
	"mM7",
	"mM7b6",
	"mM9",
	"mM9b6",
	"mMaj7",
	"mMaj7b6",
	"mMaj9",
	"mMaj9b6",
	"madd4",
	"madd9",
	"maj#5",
	"maj13",
	"maj13#11",
	"maj7",
	"maj7#11",
	"maj7#5",
	"maj9",
	"maj9#11",
	"maj9#5",
	"mb5",
	"mb6",
	"mb6M7",
	"mb6b9",
	"o",
	"o7",
	"o7M7",
	"oM7",
	"phryg",
	"sus",
	"sus2",
	"sus24",
	"sus4",
	"susb9"
	);
}
function gv()
{
	// global variables
	
	var dirPath = ""; 
	
	var wholeBarDuration = 4; // duration of a bar when meter is 4/4
	
	var anz_measures = 0;
	
	// this is the last harmony found
	// could be, that the harmony goes over two or more measures
	// these missing harmonies are replaced with the last known harmony
	var harmony_last = "";
	
	var durationOfMeasure = 0;
	var softwareVersion = 1;
	var durationOf32tel = 1.5;
	var divisions = 0;
	var beats = 4;
	var beat_type = 4
	
	var allChords;
}

function getSoftwareVersion(el)
{
	var myVersion = el.elementsByTagName("software").at(0).toElement().text();
	myVersion = myVersion.replace("MuseScore ", "");
	if(myVersion.substr(0,2) == '1.')
		return 1;
	else if(myVersion.substr(0,2) == '2.')
		return 2;
	else
		return 0;	
}
function getKey(aktMeasure, measure)
{
	return aktMeasure.elementsByTagName("attributes").at(0).toElement().
		elementsByTagName("key").at(0).toElement().
		elementsByTagName("fifths").at(0).toElement().text();
 }
function getDivisions(aktMeasure, measure)
{
	return aktMeasure.elementsByTagName("attributes").at(0).toElement().
		elementsByTagName("divisions").at(0).toElement().text();
 }

function getMeter(aktMeasure, measure)
{
	// assuming 4/4 if no meter in first bar found
	var meter = "4 4";
	
	gv.beats = aktMeasure.elementsByTagName("time").at(0).toElement().
                elementsByTagName("beats").at(0).toElement().text();

	gv.beat_type = aktMeasure.elementsByTagName("time").at(0).toElement().
                elementsByTagName("beat-type").at(0).toElement().text();

	//MB("beats: " + beats);
	if(gv.beats == "")
	{
		MB("no beat defined, assuming 4/4")
		gv.beats = 4;
		gv.beat_type = 4;
	}
	meter = gv.beats + " " + gv.beat_type;
		
	return meter;
}
function setWholeBarDuration()
{
	if(gv.beat_type == "2")
		gv.wholeBarDuration = gv.beats * gv.divisions * 2;
	else if(gv.beat_type == "4")
		gv.wholeBarDuration = gv.beats * gv.divisions;                
	else if(gv.beat_type == "8")
		gv.wholeBarDuration = gv.beats * gv.divisions/2;
	else
		gv.wholeBarDuration = gv.beats * gv.divisions ;
}

function getTempo(aktMeasure, measure)
{
	var tempo = aktMeasure.elementsByTagName("sound").at(0).toElement().text();
 
	if(tempo != "")
		tempo += ".0"

	return tempo;
}
function getCredit(doc, get_cred) {
    var cred_val = 'unknown';
	var element;
	
	if(gv.softwareVersion == 1)
	{
		var credit = doc.elementsByTagName("credit-words");
		for(var i=0;i<credit.count(); i++)
		{
			element = credit.at(i).toElement();
			if(get_cred == "title")
			{
				if(element.attribute('justify') == "center")
					return element.text();
			}
			if(get_cred == "composer")
			{
				if(element.attribute('justify') == "right")
					return element.text();
			}
		}
	}
	else if(gv.softwareVersion == 2)
	{
		try {
		  cred_val = doc.elementsByTagName("credit").at(xml_mapping[get_cred]).
				toElement().text();
		} catch(err){
		  //msg_box("get title error: " + err);
		}
	}
    return cred_val;
}

function getXMLDataFromFile()
{
	var line = "";
	var xml = "";
	var xmlFile = QFileDialog.getOpenFileName(this, "MuseScore: Load MusicXML File", defaultOpenDir, "XML file (*.xml)");
	//var gv = new globVars();
	
	if(xmlFile == "")
	{
		MB("no file selected!")
		return "-1";
	}
	
	// save the path for following save-dialog
	gv.dirPath = xmlFile;
	
	//read xml file
	var file = new QFile(xmlFile);
		
	if ( !file.open(QIODevice.ReadOnly) ) 
	{       
		MB("cannot open file: " + xmlFile)
		return "-1";
	}
	
	// file opened successfully

	// read the file
	var qTextStream = new QTextStream( file ); // use a text stream
	var cnt = 0;
	do 
	{
		line = qTextStream.readLine(); // line of text excluding '\n'
		if(line != "")
		{
			// adding all lines to one variable
			xml += line + "\n";
		}

		cnt++;
	} while (!qTextStream.atEnd());     
	//} while (line);     
			
	// Close the file
	file.close();
	
	if(xml == "")
	{
		MB("file has no data");
		return "-1";
	}
	
	// now all data in one string
	return xml;
}
function isValidChord(harmony)
{
	var valid1 = false;
	var valid2 = false;
	var chordRest = "";
	//MB("harmony: " + harmony);
	if(
		harmony.substring(0,1).toLowerCase() == "a" ||
		harmony.substring(0,1).toLowerCase() == "b" ||
		harmony.substring(0,1).toLowerCase() == "c" ||
		harmony.substring(0,1).toLowerCase() == "d" ||
		harmony.substring(0,1).toLowerCase() == "e" ||
		harmony.substring(0,1).toLowerCase() == "f" ||
		harmony.substring(0,1).toLowerCase() == "g" ||
		harmony.substring(0,1).toLowerCase() == "h")
	valid1 = true;
	
	if(valid1 && (harmony.substring(1) == "b" 
		|| harmony.substring(1) == "#" 
		|| harmony.substring(1) == "+"
		//|| (harmony.substring(1) == "-" && harmony.substring(2) != "")
		)
		)
		valid2 = true;
	
	if(valid1)
	{
		if(valid2) 
			chordRest = harmony.substring(2)
		else
			chordRest = harmony.substring(1)
	}
	//MB("harmony: " + harmony + " valid1: " + valid1 + " valid2: " + valid2 + " chordRest: " + chordRest);
	if(chordRest.trim().length > 0)
	{
		for(var i=0;i<gv.allChords.length;i++)
		{
			if(gv.allChords[i] == chordRest)
				return true;
		}
	}
	return false;
}
function getHarmonyOfMeasure(aktMeasure, measure)
{
	
	// returns the harmonies of the given measure
	
	var harmonyMeasure = "";
	var harmony = "";
	var tagName;
	var element;
	
	for(var n = aktMeasure.firstChild(); !n.isNull(); n = n.nextSibling())
	{
		element = n.toElement();
		tagName = element.tagName()

		//if(measure == 7)
			//MB("m7 tagName: " + tagName);
		if(tagName == "harmony")
		{
			harmony = getMyHarmony(element, measure);
			/*
			if(measure == 32)
				MB("m7 harmony: " + harmony);
			*/
		}
		else if	(tagName == "direction")
		{
			harmony = element.
				elementsByTagName("direction-type").at(0).toElement().
				elementsByTagName("words").at(0).toElement().text();
				
			/*
			if(measure == 32)
				MB("m7 direction: " + harmony + " vc: " + isValidChord(harmony));
			*/
			harmony = harmony.replace("-", "m")
			
			// Check if harmony is a valid chordname
			if(!isValidChord(harmony))
				harmony = "";
		}
		else
			continue;

		if(harmony != gv.harmony_last)
			harmonyMeasure += " " + harmony;

		gv.harmony_last = harmony;
	}

	//MB("m: " + measure + " h: " + harmony)
	return harmonyMeasure.trim();
}

function getMelodyOfMeasure(aktMeasure, measure)
{
	var melody = "";
	var note = "";
	
	var cntNotes = aktMeasure.elementsByTagName("note").count();
	
	//if(measure == 14)
		//MB("measure: " + (measure+1) + " cntNotes: " + cntNotes);

		
	// go through all notes in the given measure
	for(var i=0;i<cntNotes;i++)
	{      
		// no chord notes allowed
		if(aktMeasure.elementsByTagName("note").at(i).toElement().elementsByTagName("chord").count() > 0)
			continue;
			
		note = getMyNote(aktMeasure.elementsByTagName("note").at(i).toElement(), measure);
		
		if(note != "")
			melody += note + " ";		
	}
	return melody;
}

function getMyHarmony(xmlHarmony, measure)
{
	var harmony = "";

	var root_step = xmlHarmony.
		elementsByTagName('root').at(0).toElement().
		elementsByTagName('root-step').at(0).toElement().text();
	var root_alter = xmlHarmony.
		elementsByTagName('root').at(0).toElement().
		elementsByTagName('root-alter').at(0).toElement().text();
	var kind_text = xmlHarmony.elementsByTagName('kind').at(0).toElement().attribute('text');
	var bass_step = xmlHarmony.elementsByTagName('bass-step').at(0).toElement().text();
	
	//if(measure == "17")
		//MB("kind_text: " + kind_text);
	// corrections
	kind_text = kind_text.replace("ma", "maj")
	kind_text = kind_text.replace("majj", "maj")
	kind_text = kind_text.replace("mi", "m")
	kind_text = kind_text.replace("-(maj7)", "mM7")
		
	// build the harmony in the syntax of Impro-Visor
	harmony += root_step 
	if(root_alter == "-1")
		harmony += "b"
	if(root_alter == "1")
		harmony += "#"

	harmony += kind_text 
	
	if(bass_step != "")
	{
		harmony += "/" + bass_step;
		//MB("harmony: " + harmony)
	}
	
	harmony += " ";

	return harmony;
}

function getMyNote(xmlNote, measure)
{
	var note = "";

	// all possible tags of the xmlNote
	var type = xmlNote.elementsByTagName('type').at(0).toElement().text();
	var rest = xmlNote.elementsByTagName('rest').at(0).toElement().text();
	var accidental = xmlNote.elementsByTagName('accidental').at(0).toElement().text();
	var duration = xmlNote.elementsByTagName('duration').at(0).toElement().text();
	var dot = xmlNote.elementsByTagName('dot').count();
	var actual_notes = xmlNote.elementsByTagName('actual-notes').at(0).toElement().text();
	var step = xmlNote.elementsByTagName('step').at(0).toElement().text().toLowerCase();
	var octave = xmlNote.elementsByTagName('octave').at(0).toElement().text();
	var alter = xmlNote.elementsByTagName('alter').at(0).toElement().text();
	var notehead = xmlNote.elementsByTagName('notehead').at(0).toElement().text();
	var tie = xmlNote.elementsByTagName('tie').at(0).toElement().attribute('type');
	var slur = xmlNote.elementsByTagName('slur').at(0).toElement().attribute('type');
	var voice = xmlNote.elementsByTagName('voice').at(0).toElement().text();
	
	if(voice != 1)
		return "";
	//if(measure == 4)
		//MB("measure: " + measure + " duration: " + duration);
		
	if(tie == "stop")
		note += "tstop"
	else if(slur == "stop")
		note += "sstop"
	else
	{
		if(notehead == "slash")
		{
			// a slash is replaced with a rest, no accidental, no alter
			note += "r"
			accidental = "";
			alter = "";
		}
		else if(step != "")
			note += step;
		else
			note += "r"
			
		// accidental
		if(accidental == "sharp") note += "#"
		if(accidental == "flat") note += "b"
		
		if(step == "c" && alter == "-1")
			octave--;
			
		if(accidental != "") alter = "";
		
		// alter
		if(alter == "-1") note += "b"
		if(alter == "1") note += "#"
				
		// octave
		if(octave == "2") note += "--"
		if(octave == "3") note += "-"
		if(octave == "5") note += "+"
		if(octave == "6") note += "++"
	}
	
	// type, if no type specified, then take whole note
	var noteType = "1";
	
	if(type == "quarter") noteType = "4"
	if(type == "eighth") noteType = "8"
	if(type == "half") noteType = "2"	
	if(type == "whole") noteType = "1"	
	if(type == "16th") noteType = "16"	
	if(type == "32th") noteType = "32"	
	
	note += noteType;
	
	// add a dot if needed
	if(dot == 1)
		note += ".";
	if(dot == 2)
		note += "..";
		
	// irregular time
	if(actual_notes != "") note += "/" + actual_notes
	
	if(tie == "start")
		note += "tstart"
	if(slur == "start")
		note += "sstart"
		
	// duration of the measure
	gv.durationOfMeasure += parseInt(duration);
	//if(measure == 4)
		//MB("measure: " + measure + " gv.durationOfMeasure: " + gv.durationOfMeasure);
	return note;
}
function writeFile(title, meter, melody, harmony, composer, tempo, durationOfMeasure, key)
{

	var lsFile = QFileDialog.getSaveFileName(this, "MuseScore: Output-File", gv.dirPath.replace(".xml", ".ls"), "ls file (*.ls)");
	var result = "";

	if(lsFile == "")
	{
		MB("no output file selected.")
		return false;
	}
	
	var file = new QFile(lsFile);
	if (!file.open(QIODevice.WriteOnly) ) 
	{
		MB("couldn't open output file")
		return false;
	}


	// file opened successfully
	
	
	result = file.write(new QByteArray("(title " + title + ")\n"));
	result = file.write(new QByteArray("(meter " + meter + ")\n"));
	result = file.write(new QByteArray("(key " + key + ")\n"));
	result = file.write(new QByteArray("(composer " + composer + ")\n"));
	result = file.write(new QByteArray("(tempo " + tempo + ")\n"));
	result = file.write(new QByteArray("(volume 127)\n"));
	result = file.write(new QByteArray("(bass-volume 100)\n"));
	result = file.write(new QByteArray("(drum-volume 100)\n"));
	result = file.write(new QByteArray("(drum-volume 100)\n"));	
	result = file.write(new QByteArray("(chord-volume 100)\n"));	
	
	var myKey =	"(part" +
    "(type melody)" +
    "(title )" +
    "(composer )" +
    "(instrument 0)" +
    "(volume 65)" +
    "(key " + key + ")" +
	")";
	//MB("mk: " + myKey);
	
	result = file.write(new QByteArray(myKey +"\n"));



	var timingError = "";
	
	var mel = "";
	
	// write melody
	for(var i=0;i<melody.length; i++)
	{
		if(durationOfMeasure[i] != gv.wholeBarDuration)
		{
			if(debug)
				timingError += ", Takt " + (i+1) + " durationOfMeasure: " + durationOfMeasure[i] + " wholeBarDuration: " + gv.wholeBarDuration + "\n";
				
			timingError += ", " + (i+1);
			melody[i] = "r1";
		}
		
		if(meter == "4 4")
		{
			// show a whole bar rest instead of 4 quarter rests
			mel = mel.replace(" r4 r4 r4 r4 ", " r1 ");
		}
		else if(meter == "3 4")
		{
			// show a whole bar rest instead of 3 quarter rests
			mel = mel.replace(" r4 r4 r4 ", " r1 ");
		}
	
		mel += melody[i] + " ";
	}


	
	mel = mel.replace(/  /g, " ");
	mel = mel.replace(/tstart tstop/g, "+");
	mel = mel.replace(/sstart sstop/g, "+");
	mel = mel.replace(/ tstop/g, "+");
	mel = mel.replace(/ sstop/g, "+");
	mel = mel.replace(/tstart/g, "");
		
	file.write(new QByteArray(mel + "\n"));

	result = file.write(new QByteArray("\n\n"))
	
	// write harmony
	for(var i=0;i<harmony.length; i++)
	{
		if(i%4 != 0)
			file.write(new QByteArray(" "));
			
		file.write(new QByteArray(harmony[i] + " |"));
		if((i+1)%4 == 0)
			file.write(new QByteArray("\n"));
	}
	file.close();
	
	if(timingError.length > 0)
	{
		MB("Timing error in following bar(s): " + timingError.substr(1) + "\nMelody is replaced by a rest.");
		return false; // display no more messagebox
	}
	return true;
}				


function MB(s)
{
	mb = new QMessageBox();
	mb.setWindowTitle("MuseScore: XML2Impro-Visor Plugin");
	mb.text = s;
	mb.exec();
}

//---------------------------------------------------------
//    menu:  defines were the function will be placed
//           in the menu structure
//---------------------------------------------------------
var mscorePlugin = {
      majorVersion: 1,
      minorVersion: 1,
      menu: 'Plugins.XML2Impro-Visor',
      init: init,
      run:  run
      };

mscorePlugin;


